@@ -43,6 +43,7 @@ use Psr\Http\Message\ResponseInterface;
 use Psr\Http\Message\ServerRequestInterface;
 use Psr\Http\Message\StreamFactoryInterface;
 use Psr\Log\LoggerInterface;
+use Teapot\StatusCode;
 
 abstract readonly class AbstractShowAction implements ApplicationActionInterface
 {
@@ -62,35 +63,42 @@ abstract readonly class AbstractShowAction implements ApplicationActionInterface
         $response = $this->responseFactory->createResponse();
 
         if (
+            $this->configContainer->isFeatureEnabled(ConfigurationKeyEnum::PUBLIC_IMAGES) === false &&
             $this->configContainer->isFeatureEnabled(ConfigurationKeyEnum::USE_AUTH) === true &&
             $this->configContainer->isFeatureEnabled(ConfigurationKeyEnum::REQUIRE_SESSION) === true
         ) {
-            $auth  = $this->requestParser->getFromRequest('auth');
-            $user  = $this->requestParser->getFromRequest('u');
-            $token = $this->requestParser->getFromRequest('t');
-            $salt  = $this->requestParser->getFromRequest('s');
-            // Check to see if they've got an interface session or a valid API session
+            // regular auth
+            $auth = $this->requestParser->getFromRequest('auth');
+            // subsonic apiKey auth
+            $apiKey = $this->requestParser->getFromRequest('apiKey');
+            // subsonic token and salt auth
             $token_check = $this->authenticationManager->tokenLogin(
-                $user,
-                $token,
-                $salt
+                $this->requestParser->getFromRequest('u'),
+                $this->requestParser->getFromRequest('t'),
+                $this->requestParser->getFromRequest('s')
             );
 
-            $cookie = $_COOKIE[AmpConfig::get('session_name')] ?? '';
+            $cookie = $_COOKIE[AmpConfig::get('session_name', 'ampache')] ?? null;
 
+            // Check to see if they've got an interface session or a valid API session
             if (
-                !Session::exists(AccessTypeEnum::INTERFACE->value, $cookie) &&
-                !Session::exists(AccessTypeEnum::API->value, $auth) &&
-                !empty($token_check)
+                Session::exists(AccessTypeEnum::INTERFACE->value, $cookie ?? $auth) ||
+                Session::exists(AccessTypeEnum::API->value, (empty($auth)) ? $apiKey : $auth) ||
+                (isset($token_check['success']) && $token_check['success'] === true)
             ) {
-                $auth = ($auth !== '') ? $auth : $token;
+                // authentication succeeded
+            } else {
                 $this->logger->warning(
-                    sprintf('Access denied, checked cookie session:%s and auth:%s', $cookie, $auth),
+                    'Access denied: No valid session found',
                     [LegacyLogger::CONTEXT_TYPE => self::class]
                 );
 
-                return $response;
+                return $response->withStatus(
+                    StatusCode\RFC\RFC7231::FORBIDDEN,
+                    'Access denied: No valid session found'
+                );
             }
+
         }
 
         // If we aren't resizing just trash thumb
@@ -103,7 +111,7 @@ abstract readonly class AbstractShowAction implements ApplicationActionInterface
         $size  = ($thumb === 0)
             ? filter_input(INPUT_GET, 'size', FILTER_SANITIZE_SPECIAL_CHARS, FILTER_NULL_ON_FAILURE) ?? 'original'
             : 'original';
-        $kind  = (array_key_exists('kind', $_GET) && $_GET['kind'] == 'preview')
+        $kind = (array_key_exists('kind', $_GET) && $_GET['kind'] == 'preview')
             ? 'preview'
             : 'default';
 
@@ -123,7 +131,8 @@ abstract readonly class AbstractShowAction implements ApplicationActionInterface
                     // If we need to pull the data out of the session
                     if (array_key_exists('form', $_SESSION)) {
                         $filename    = $this->requestParser->getFromRequest('image_index');
-                        $image       = Art::get_from_source($_SESSION['form']['images'][$filename], 'album');
+                        $object_type = $this->requestParser->getFromRequest('object_type');
+                        $image       = Art::get_from_source($_SESSION['form']['images'][$filename], $object_type);
                         $mime        = $_SESSION['form']['images'][$filename]['mime'];
                         $typeManaged = true;
                     }
@@ -134,7 +143,10 @@ abstract readonly class AbstractShowAction implements ApplicationActionInterface
             $itemConfig = $this->getFileName($request);
 
             if ($itemConfig === null) {
-                return $response;
+                return $response->withStatus(
+                    StatusCode\RFC\RFC7231::NOT_FOUND,
+                    'Bad Request: Invalid URL'
+                );
             }
 
             [$filename, $objectId, $type] = $itemConfig;
@@ -156,15 +168,13 @@ abstract readonly class AbstractShowAction implements ApplicationActionInterface
                         ? $rootimg . "blankalbum_" . $size . ".png"
                         : $rootimg . "blankalbum.png";
                 }
-                $etag  = ($has_size && in_array($size, ['128x128', '256x256', '384x384', '768x768']))
+                $etag = ($has_size && in_array($size, ['128x128', '256x256', '384x384', '768x768']))
                     ? "EmptyMediaAlbum" . $size
                     : "EmptyMediaAlbum";
                 $image = file_get_contents($defaultimg);
             } else {
                 // show the original image or thumbnail
-                $etag = ($art->id > 0)
-                    ? $art->id
-                    : null;
+                $etag       = $type . '_' . $art->id . '_' . $size;
                 $thumb_data = [];
                 if ($has_size) {
                     if ($art->thumb && $art->thumb_mime) {
@@ -174,12 +184,12 @@ abstract readonly class AbstractShowAction implements ApplicationActionInterface
                     }
                 } elseif (array_key_exists('thumb', $_GET) && $thumb > 0) {
                     // thumbs should be avoided but can still be used
-                    $size       = Art::get_thumb_size($thumb);
-                    $thumb_data = $art->get_thumb($size);
-                    $etag       = null;
+                    $size_array = Art::get_thumb_size($thumb);
+                    $thumb_data = $art->get_thumb($size_array);
+                    $etag       = $type . '_' . $art->id . '_thumb_' . $thumb;
                 }
 
-                $mime  = (array_key_exists('thumb_mime', $thumb_data))
+                $mime = (array_key_exists('thumb_mime', $thumb_data))
                     ? $thumb_data['thumb_mime']
                     : $art->raw_mime;
                 $image = (array_key_exists('thumb', $thumb_data))
@@ -212,7 +222,7 @@ abstract readonly class AbstractShowAction implements ApplicationActionInterface
             // That means the client has a cached version of the image
             $reqheaders = getallheaders();
             if (is_array($reqheaders) && array_key_exists('If-Modified-Since', $reqheaders) && array_key_exists('If-None-Match', $reqheaders)) {
-                if (!array_key_exists('Cache-Control', $reqheaders) || (array_key_exists('Cache-Control', $reqheaders) && $reqheaders['Cache-Control'] != 'no-cache')) {
+                if (!array_key_exists('Cache-Control', $reqheaders) || ($reqheaders['Cache-Control'] != 'no-cache')) {
                     $cetag = str_replace('"', '', $reqheaders['If-None-Match']);
                     // Same image than the cached one? Use the cache.
                     if (
