@@ -95,8 +95,7 @@ class Album extends database_object implements library_item, CatalogItemInterfac
     /** @var int[] $song_artists */
     public ?array $song_artists = null;
 
-    /** @var int $catalog_id */
-    public $catalog_id;
+    public int $catalog_id = 0;
 
     /** @var string $artist_prefix */
     public $artist_prefix;
@@ -109,7 +108,7 @@ class Album extends database_object implements library_item, CatalogItemInterfac
     /** @var int[] $album_artists */
     private ?array $album_artists = null;
 
-    /** @var list<array{id: int, name: string, is_hidden: int, count: int}> $tags */
+    /** @var array<int, array{id: int, name: string, is_hidden: int, count: int}> $tags */
     private ?array $tags = null;
 
     private ?string $f_artist_name = null;
@@ -226,11 +225,11 @@ class Album extends database_object implements library_item, CatalogItemInterfac
         ?string $version = null,
         bool $readonly = false
     ): int {
-        $trimmed        = Catalog::trim_prefix(trim((string) $name));
-        $name           = $trimmed['string'];
-        $prefix         = $trimmed['prefix'];
-        $album_artist   = (int)$album_artist;
-        $album_artist   = ($album_artist < 1) ? null : $album_artist;
+        $trimmed      = Catalog::trim_prefix(trim((string) $name));
+        $name         = $trimmed['string'];
+        $prefix       = $trimmed['prefix'];
+        $album_artist = (int)$album_artist;
+        $album_artist = ($album_artist < 1) ? null : $album_artist;
 
         $mbid           = (empty($mbid)) ? null : $mbid;
         $mbid_group     = (empty($mbid_group)) ? null : $mbid_group;
@@ -409,7 +408,7 @@ class Album extends database_object implements library_item, CatalogItemInterfac
             $this->has_art = Art::has_db($this->id, 'album');
         }
 
-        return $this->has_art;
+        return $this->has_art ?? false;
     }
 
     /**
@@ -498,7 +497,7 @@ class Album extends database_object implements library_item, CatalogItemInterfac
             $this->link = $web_path . '/albums.php?action=show&album=' . $this->id;
         }
 
-        return $this->link;
+        return $this->link ?? '';
     }
 
     /**
@@ -516,7 +515,7 @@ class Album extends database_object implements library_item, CatalogItemInterfac
 
     /**
      * Get item tags.
-     * @return list<array{id: int, name: string, is_hidden: int, count: int}>
+     * @return array<int, array{id: int, name: string, is_hidden: int, count: int}>
      */
     public function get_tags(): array
     {
@@ -524,7 +523,7 @@ class Album extends database_object implements library_item, CatalogItemInterfac
             $this->tags = Tag::get_top_tags('album', $this->id);
         }
 
-        return $this->tags;
+        return $this->tags ?? [];
     }
 
     /**
@@ -628,6 +627,7 @@ class Album extends database_object implements library_item, CatalogItemInterfac
     public function findAlbumArtist(): ?int
     {
         if (
+            $this->isNew() === false &&
             !$this->album_artist &&
             $this->song_artist_count == 1
         ) {
@@ -888,7 +888,7 @@ class Album extends database_object implements library_item, CatalogItemInterfac
         $changed    = [];
         $songs      = $this->getSongRepository()->getByAlbum($this->id);
         // run an album check on the current object READONLY means that it won't insert a new album
-        $album_id   = self::check(
+        $album_id = self::check(
             $this->catalog,
             $name,
             $year,
@@ -1132,8 +1132,8 @@ class Album extends database_object implements library_item, CatalogItemInterfac
         if ($album_id > 0 && $object_id > 0) {
             // Remove the album_map if this was the last track
             $sql = ($object_type == 'album')
-                ? "SELECT `artist_id` FROM `artist_map` WHERE `artist_id` = ? AND `object_id` = ? AND object_type = ?;"
-                : "SELECT `artist_id` FROM `artist_map` WHERE `artist_id` = ? AND `object_id` IN (SELECT `id` FROM `song` WHERE `album` = ?) AND object_type = ?;";
+                ? "SELECT `artist_id` FROM `artist_map` WHERE `artist_id` = ? AND `object_id` = ? AND `object_type` = ?;"
+                : "SELECT `artist_id` FROM `artist_map` WHERE `artist_id` = ? AND `object_id` IN (SELECT `id` FROM `song` WHERE `album` = ?) AND `object_type` = ?;";
             $db_results = Dba::read($sql, [$object_id, $album_id, $object_type]);
             $row        = Dba::fetch_assoc($db_results);
             if ($row === []) {
