@@ -209,7 +209,7 @@ class Podcast_Episode extends database_object implements
             $this->has_art = Art::has_db($this->podcast, 'podcast');
         }
 
-        return $this->has_art;
+        return $this->has_art ?? false;
     }
 
     /**
@@ -252,7 +252,7 @@ class Podcast_Episode extends database_object implements
             $this->link = $web_path . '/podcast_episode.php?action=show&podcast_episode=' . $this->id;
         }
 
-        return $this->link;
+        return $this->link ?? '';
     }
 
     /**
@@ -287,8 +287,8 @@ class Podcast_Episode extends database_object implements
             return $min . ":" . $sec;
         }
 
-        $hour           = sprintf("%02d", floor($min / 60));
-        $min_h          = sprintf("%02d", ($min % 60));
+        $hour  = sprintf("%02d", floor($min / 60));
+        $min_h = sprintf("%02d", ($min % 60));
 
         return $hour . ":" . $min_h . ":" . $sec;
     }
@@ -306,8 +306,8 @@ class Podcast_Episode extends database_object implements
     public function getPodcastLink(): string
     {
         if ($this->podcast_link === null) {
-            $podcast              = $this->getPodcastRepository()->findById($this->podcast);
-            $this->podcast_link   = (string)$podcast?->get_f_link();
+            $podcast            = $this->getPodcastRepository()->findById($this->podcast);
+            $this->podcast_link = (string)$podcast?->get_f_link();
         }
 
         return $this->podcast_link;
@@ -435,24 +435,24 @@ class Podcast_Episode extends database_object implements
      * update
      * This takes a key'd array of data and updates the current podcast episode
      * @param array{
-     *      title?: string,
-     *      website?: string,
-     *      category: ?string,
-     *      description?: ?string,
-     *      author?: ?string,
-     *  } $data
+     *     title?: string,
+     *     website?: string,
+     *     category: ?string,
+     *     description?: ?string,
+     *     author?: ?string,
+     * } $data
      */
     public function update(array $data): int
     {
-        $title    = $data['title'] ?? $this->title;
-        $website  = (isset($data['website']))
+        $title   = $data['title'] ?? $this->title;
+        $website = (isset($data['website']))
             ? filter_var(urldecode($data['website']), FILTER_VALIDATE_URL) ?: null
             : null;
         $category = $data['category'] ?? null;
         /** @var string $description */
         $description = (isset($data['description'])) ? scrub_in(Dba::check_length((string)$data['description'], 4096)) : null;
         /** @var string $author */
-        $author   = (isset($data['author'])) ? scrub_in(Dba::check_length((string)$data['author'], 64)) : null;
+        $author = (isset($data['author'])) ? scrub_in(Dba::check_length((string)$data['author'], 64)) : null;
 
         $sql = 'UPDATE `podcast_episode` SET `title` = ?, `website` = ?, `description` = ?, `author` = ?, `category` = ? WHERE `id` = ?';
         Dba::write($sql, [$title, $website, $description, $author, $category, $this->id]);
@@ -471,10 +471,10 @@ class Podcast_Episode extends database_object implements
      * this checks to see if the current object has been played
      * if not then it sets it to played. In any case it updates stats.
      * @param array{
-     *      latitude?: float,
-     *      longitude?: float,
-     *      name?: string
-     *  } $location
+     *     latitude?: float,
+     *     longitude?: float,
+     *     name?: string
+     * } $location
      */
     public function set_played(int $user_id, string $agent, array $location, int $date): bool
     {
@@ -534,9 +534,9 @@ class Podcast_Episode extends database_object implements
      * It takes a field, value podcast_episode_id and level. first and foremost it checks the level
      * against Core::get_global('user') to make sure they are allowed to update this record
      * it then updates it and sets $this->{$field} to the new value
-     * @param string|int $value
+     * @param int|string $value
      */
-    private static function _update_item(string $field, $value, int $episode_id): void
+    private static function _update_item(string $field, int|string $value, int $episode_id): void
     {
         /* Check them Rights! */
         if (!Access::check(AccessTypeEnum::INTERFACE, AccessLevelEnum::USER)) {
@@ -585,13 +585,8 @@ class Podcast_Episode extends database_object implements
      * This function takes all the song information and correctly formats a
      * stream URL taking into account the downsmapling mojo and everything
      * else, this is the true function
-     * @param string $additional_params
-     * @param string $player
-     * @param bool $local
-     * @param int|string|false $uid
-     * @param null|string $streamToken
      */
-    public function play_url($additional_params = '', $player = '', $local = false, $uid = false, $streamToken = null): string
+    public function play_url(string $additional_params = '', string $player = '', bool $local = false, int|string|null $uid = null, ?string $streamToken = null): string
     {
         if ($this->isNew() || !isset($this->type)) {
             return '';
