@@ -87,6 +87,7 @@ class Search extends playlist_object
 
     public $types = []; // rules that are available to the objectType (title, year, rating, etc)
 
+    /** @var array<string, array<int, array{name: string, description: string, sql: string, preg_match?: string|array{string, string}, preg_replace?:string|array{string, string}}>> $basetypes */
     public $basetypes = []; // rule operator subtypes (numeric, text, boolean, etc)
 
     private SearchInterface $searchType;
@@ -447,7 +448,7 @@ class Search extends playlist_object
             'description' => T_('Limit'),
             'sql' => '`date`',
         ];
-        $this->basetypes['recent_added'][]  = [
+        $this->basetypes['recent_added'][] = [
             'name' => 'add',
             'description' => T_('Limit'),
             'sql' => '`addition_time`',
@@ -691,22 +692,22 @@ class Search extends playlist_object
         $t_file_data = T_('File Data');
         $this->_add_type_text('file', T_('Filename'), $t_file_data);
         $bitrate_array = [
-            '32',
-            '40',
-            '48',
-            '56',
-            '64',
-            '80',
-            '96',
-            '112',
-            '128',
-            '160',
-            '192',
-            '224',
-            '256',
-            '320',
-            '640',
-            '1280',
+            '32' => '32',
+            '40' => '40',
+            '48' => '48',
+            '56' => '56',
+            '64' => '64',
+            '80' => '80',
+            '96' => '96',
+            '112' => '112',
+            '128' => '128',
+            '160' => '160',
+            '192' => '192',
+            '224' => '224',
+            '256' => '256',
+            '320' => '320',
+            '640' => '640',
+            '1280' => '1280',
         ];
         $this->_add_type_select('bitrate', T_('Bitrate'), 'numeric', $bitrate_array, $t_file_data);
         $this->_add_type_date('added', T_('Added'), $t_file_data);
@@ -1201,6 +1202,7 @@ class Search extends playlist_object
      * get_searches
      *
      * Return the IDs of all saved searches accessible by the current user.
+     * @return array<int, array{id: int, name: string}>
      */
     public static function get_searches(?int $user_id = null): array
     {
@@ -1227,7 +1229,10 @@ class Search extends playlist_object
         $db_results = Dba::read($sql, $params);
         $results    = [];
         while ($row = Dba::fetch_assoc($db_results)) {
-            $results[$row['id']] = $row['name'];
+            $results[] = [
+                'id' => (int)$row['id'],
+                'name' => $row['name']
+            ];
         }
 
         parent::add_to_cache($key, $user_id, $results);
@@ -1810,6 +1815,18 @@ class Search extends playlist_object
         return null;
     }
 
+    /**
+     * get_rule_types
+     *
+     * Return rule list for the current search type
+     * @return array<string, array<string, mixed>>
+     */
+    public function get_rule_types(): array
+    {
+        return $this->types;
+    }
+
+
     /**
      * set_rules
      *
@@ -1978,9 +1995,9 @@ class Search extends playlist_object
      * @param string $data
      * @param string $type
      * @param array{
-     *     name: string,
-     *     description: string,
-     *     sql: string,
+     *     name?: string,
+     *     description?: string,
+     *     sql?: string,
      *     preg_match?: string|array,
      *     preg_replace?: string|array,
      * } $operator
